package Test::Run::Iface;

use strict;
use warnings;

use MRO::Compat;

1;

=head1 NAME

Test::Run::Iface  

=head1 LICENSE

This file is licensed under the MIT X11 License:

http://www.opensource.org/licenses/mit-license.php

=cut
